# sentier_glossary

[![PyPI](https://img.shields.io/pypi/v/sentier_glossary.svg)][pypi status]
[![Status](https://img.shields.io/pypi/status/sentier_glossary.svg)][pypi status]
[![Python Version](https://img.shields.io/pypi/pyversions/sentier_glossary)][pypi status]
[![License](https://img.shields.io/pypi/l/sentier_glossary)][license]

[![Read the documentation at https://sentier_glossary.readthedocs.io/](https://img.shields.io/readthedocs/sentier_glossary/latest.svg?label=Read%20the%20Docs)][read the docs]
[![Tests](https://github.com/Depart-de-Sentier/sentier_glossary/actions/workflows/python-test.yml/badge.svg)][tests]
[![Codecov](https://codecov.io/gh/Depart-de-Sentier/sentier_glossary/branch/main/graph/badge.svg)][codecov]

[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)][pre-commit]
[![Black](https://img.shields.io/badge/code%20style-black-000000.svg)][black]

[pypi status]: https://pypi.org/project/sentier_glossary/
[read the docs]: https://sentier_glossary.readthedocs.io/
[tests]: https://github.com/Depart-de-Sentier/sentier_glossary/actions?workflow=Tests
[codecov]: https://app.codecov.io/gh/Depart-de-Sentier/sentier_glossary
[pre-commit]: https://github.com/pre-commit/pre-commit
[black]: https://github.com/psf/black

## Installation

You can install _sentier_glossary_ via [pip] from [PyPI]:

```console
$ pip install sentier_glossary
```

## Contributing

Contributions are very welcome.
To learn more, see the [Contributor Guide][Contributor Guide].

## License

Distributed under the terms of the [MIT license][License],
_sentier_glossary_ is free and open source software.

## Issues

If you encounter any problems,
please [file an issue][Issue Tracker] along with a detailed description.


<!-- github-only -->

[command-line reference]: https://sentier_glossary.readthedocs.io/en/latest/usage.html
[License]: https://github.com/Depart-de-Sentier/sentier_glossary/blob/main/LICENSE
[Contributor Guide]: https://github.com/Depart-de-Sentier/sentier_glossary/blob/main/CONTRIBUTING.md
[Issue Tracker]: https://github.com/Depart-de-Sentier/sentier_glossary/issues
